import { Router } from "express"
import { PrismaClient } from "@prisma/client"

const router = Router()
const prisma = new PrismaClient()

router.get("/", async (req, res) => {
    const comments = await prisma.comment.findMany({
        orderBy: [{ id: "desc" }],
    })

    return res.status(200).send(comments)
})

router.get("/:id", async (req, res) => {
    const id = parseInt(req.params.id)

    if (!id) return res.status(400).send({ message: "Invalid comment ID." })

    try {
        const comment = await prisma.comment.findUnique({
            where: { id },
        })

        if (!comment)
            return res.status(404).send({ message: "Comment not found." })

        return res.status(200).send(comment)
    } catch (error) {
        console.error(error)
    }
})

router.post("/", async (req, res) => {
    const { postId, body } = req.body as { postId: string; body: string }

    if (!body || !postId) {
        return res
            .status(400)
            .send({ message: "Comment body/post ID must be included." })
    }

    try {
        const newComment = await prisma.comment.create({
            data: { body: body, postId: parseInt(postId) },
        })
        return res.status(201).send(newComment)
    } catch (error) {
        console.error(error)
    }
})

export default router
